//+--------------------------------------------------------------------------
//|
//| rcreader.h - a parser for command line arguments
//|
//| This file is part of a larger package; see the README supplied with
//| this for information about the package, how to build and how to run
//| it.
//|
//| (c) 2002, 2020 Dietmar Koenig <http://www.faoileag.de>
//|
//| This program is free software: you can redistribute it and/or modify
//| it under the terms of the GNU General Public License as published by
//| the Free Software Foundation, either version 3 of the License, or
//| (at your option) any later version.
//|
//| This program is distributed in the hope that it will be useful,
//| but WITHOUT ANY WARRANTY; without even the implied warranty of
//| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//| GNU General Public License for more details.
//|
//| You should have received a copy of the GNU General Public License
//| along with this program.  If not, see <https://www.gnu.org/licenses/>.
//|
//+--------------------------------------------------------------------------
#include "utilities.h"

//+--------------------------------------------------------------------------+
//|                                                                          |
//| define some default values and some thresholds:                          |
//|                                                                          |
//+--------------------------------------------------------------------------+
#define XMANDELBROTARGS_FUNCTIONMANDELBROT 1
#define XMANDELBROTARGS_FUNCTIONJULIA      2

#define XMANDELBROTARGS_DEFAULTWIDTH       400
#define XMANDELBROTARGS_DEFAULTHEIGHT      400
#define XMANDELBROTARGS_DEFAULTX           170
#define XMANDELBROTARGS_DEFAULTY            90
#define XMANDELBROTARGS_DEFAULTPMIN        -2.25
#define XMANDELBROTARGS_DEFAULTPMAX        +0.75
#define XMANDELBROTARGS_DEFAULTQMAX        +1.50
#define XMANDELBROTARGS_DEFAULTQMIN        -1.50
#define XMANDELBROTARGS_DEFAULTTITLE       ""
#define XMANDELBROTARGS_DEFAULTIMMEDIATE   0
#define XMANDELBROTARGS_DEFAULTVERBOSITY   0
#define XMANDELBROTARGS_DEFAULTINFINITY    100
#define XMANDELBROTARGS_DEFAULTNOASPECT    0
#define XMANDELBROTARGS_DEFAULTFUNCTION    XMANDELBROTARGS_FUNCTIONMANDELBROT

#define XMANDELBROTARGS_MAXASPECT          2.0
#define XMANDELBROTARGS_MINASPECT          0.5
#define XMANDELBROTARGS_MAXWIDTH           1600
#define XMANDELBROTARGS_MAXHEIGHT          1200
#define XMANDELBROTARGS_MINP               -3.0
#define XMANDELBROTARGS_MAXP               +1.0
#define XMANDELBROTARGS_MAXQ               +2.0
#define XMANDELBROTARGS_MINQ               -2.0
#define XMANDELBROTARGS_MININFINITY        10
#define XMANDELBROTARGS_MAXINFINITY        10000

//+--------------------------------------------------------------------------+
//|                                                                          |
//| define the structure with all possible command line arguments:           |
//|                                                                          |
//+--------------------------------------------------------------------------+
struct args_t {
	char   progname[255];
	char   filename[1024];
	char   title[1024];
	int    immediate;
	int    verbosity;
	int    infinity;
	int    noaspect;
	int    function;
	int    x, y;
	int    width, height;
	int    canvaswidth, canvasheight;
	double pmin, pmax;
	double qmin, qmax;
};

//+--------------------------------------------------------------------------+
//|                                                                          |
//| declare the function that does the parsing:                              |
//|                                                                          |
//+--------------------------------------------------------------------------+
args_t* parseargs(int argc, char** argv);
