//+--------------------------------------------------------------------------
//|
//| xmandelbrot.h - displays a mandelbrot set in a X window
//|
//| This file is part of a larger package; see the README supplied with
//| this for information about the package, how to build and how to run
//| it.
//|
//| (c) 2002, 2020 Dietmar Koenig <http://www.faoileag.de>
//|
//| This program is free software: you can redistribute it and/or modify
//| it under the terms of the GNU General Public License as published by
//| the Free Software Foundation, either version 3 of the License, or
//| (at your option) any later version.
//|
//| This program is distributed in the hope that it will be useful,
//| but WITHOUT ANY WARRANTY; without even the implied warranty of
//| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//| GNU General Public License for more details.
//|
//| You should have received a copy of the GNU General Public License
//| along with this program.  If not, see <https://www.gnu.org/licenses/>.
//|
//+--------------------------------------------------------------------------
#include "utilities.h"
#include "xwindow.h"
#include "rcreader.h"
#include "xmandelbrotcolors.h"

//+--------------------------------------------------------------------------+
//|                                                                          |
//| Class XMandelbrot                                                        |
//|                                                                          |
//+--------------------------------------------------------------------------+
class XMandelbrot : public XWindow {
	public:
	XMandelbrot(int x, int y, int width, int height, char* title,
		int canvaswidth, int canvasheight,
		int immediate, int verbosity, char* filename,
		int infinity, int noaspect, int function,
		double pmin, double pmax, double qmax, double qmin,
		int argc, char** argv);

	protected:
	XMandelbrotColors* color;
	int cx, cy; // coordinates on canvas
	int fx, fy; // coordinates of first corner (mouse button pressed)
	int sx, sy; // coordinates of second corner (moved / button released)
	int canvastop;
	int canvasleft;
	int canvaswidth;
	int canvasheight;
	int infinity;
	int kmax;
	int immediate;
	int verbosity;
	int noaspect;
	int function;
	int recton;
	int action;
	char filenamebuf[1024];
	char prognamebuf[1024];
	char* progname;
	char* filename;
	double pmin;
	double qmin;
	double pmax;
	double qmax;
	double dp;
	double dq;

	virtual void EventLoopAction();
	virtual void EvHandlerButton1Press(XButtonEvent* event);
	virtual void EvHandlerButton1MotionNotify(XButtonEvent* event);
	virtual void EvHandlerButton1Release(XButtonEvent* event);
	virtual void EvHandlerButton2Release(XButtonEvent* event);
	virtual void EvHandlerButton3Release(XButtonEvent* event);
	virtual void EvHandlerKeyPressed(XKeyEvent* event);

	void DrawRect(int c1x, int c1y, int c2x, int c2y);
	void RemoveRect(int c1x, int c1y, int c2x, int c2y);
	void DrawPixel(int x, int y);
	void Aspect();
	void Start();
	void Zoom();
	void Save();
	void Load();
	void Quit();
	unsigned long Mandelbrot(int x, int y);
	unsigned long Julia(int x, int y);
};

